<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Memory
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function memory_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	// Sticky header.
	$classes[] = 'sticky-header';

	// Sticky sidebar.
	$classes[] = 'sticky-sidebar';

	// Check jetpack active and module subscriptions enable.
	if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) ) {
		$classes[] = 'subscriptions-enable';
	}

	// Site title.
	$site_title = get_theme_mod( 'site_title', true );
	if ( ! $site_title ) {
		$classes[] = 'site-title-hidden';
	}

	// Site description.
	$site_description = get_theme_mod( 'site_description', true );
	if ( ! $site_description ) {
		$classes[] = 'site-description-hidden';
	}

	// Footer title.
	$footer_title = get_theme_mod( 'ft_site_title', true );
	if ( ! $footer_title ) {
		$classes[] = 'footer-title-hidden';
	}

	// Footer description.
	$footer_description = get_theme_mod( 'ft_site_description', true );
	if ( ! $footer_description ) {
		$classes[] = 'footer-description-hidden';
	}

	// Adds a class of style blog.
	if ( ! is_singular() ) {
		$memory_blog_style = get_theme_mod( 'blog_style' );
		if ( 'list' === $memory_blog_style ) {
			$classes[] = 'default overlap';
		}
	}

	return $classes;
}
add_filter( 'body_class', 'memory_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function memory_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'memory_pingback_header' );
